==> haskell-list-t-1.0.5.7-30-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-list-t.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 list-t
version:              1.0.5.7
visibility:           public
id:                   list-t-1.0.5.7-Kce3kPVfPFH8fgauyBPiZn
key:                  list-t-1.0.5.7-Kce3kPVfPFH8fgauyBPiZn
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/list-t
synopsis:             ListT done right
description:
    A correct implementation of the list monad-transformer.
    Useful for basic streaming.

category:             Streaming, Data Structures, Control
abi:                  59cdf06772d7c1138028f4a7ed5a5f08
exposed:              True
exposed-modules:      ListT
hidden-modules:       ListT.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-list-t
hs-libraries:         HSlist-t-1.0.5.7-Kce3kPVfPFH8fgauyBPiZn
depends:
    base-4.17.2.1 foldl-1.4.18-5c5FYHd5uyHBYUMYoaJHy6
    logict-0.8.1.0-AYXRUri2U7A60egz9S7Vok
    mmorph-1.2.1-Dj3j5073UbJL5k7iF3E3ML
    monad-control-1.0.3.1-GptxzQqshh7J2Y4ewMk2Hl mtl-2.2.2
    transformers-0.5.6.2 transformers-base-0.4.6-9DQJFK0WHcQ1sjDWa6wyhD

haddock-interfaces:   /usr/share/doc/haskell-list-t/html/list-t.haddock
haddock-html:         /usr/share/doc/haskell-list-t/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-list-t-1.0.5.7-52-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-list-t.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 list-t
version:              1.0.5.7
visibility:           public
id:                   list-t-1.0.5.7-GdSuNSaT7D1HbJEvfXY0bP
key:                  list-t-1.0.5.7-GdSuNSaT7D1HbJEvfXY0bP
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/list-t
synopsis:             ListT done right
description:
    A correct implementation of the list monad-transformer.
    Useful for basic streaming.

category:             Streaming, Data Structures, Control
abi:                  d65d52611d6f5b0a6f677a21d474e9a1
exposed:              True
exposed-modules:      ListT
hidden-modules:       ListT.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-list-t
hs-libraries:         HSlist-t-1.0.5.7-GdSuNSaT7D1HbJEvfXY0bP
depends:
    base-4.17.2.1 foldl-1.4.18-OTrisf5BCQDMMVbl8USct
    logict-0.8.2.0-FzMNlk2koO97PeF1yy4U2a
    mmorph-1.2.1-Dj3j5073UbJL5k7iF3E3ML
    monad-control-1.0.3.1-5KQQUvViYP35kwtWEUOPGs mtl-2.2.2
    transformers-0.5.6.2 transformers-base-0.4.6-72fNkPW8m0RFmUAZLkd9QA

haddock-interfaces:   /usr/share/doc/haskell-list-t/html/list-t.haddock
haddock-html:         /usr/share/doc/haskell-list-t/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
